--
-- PostgreSQL database dump
--

-- Dumped from database version 9.5.10
-- Dumped by pg_dump version 9.5.10

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = public, pg_catalog;

--
--

CREATE FUNCTION is_more_private(statuses text[]) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	first_active integer := array_position(statuses, 'active');
	first_private integer := array_position(statuses, 'private');
	first_inactive integer := array_position(statuses, 'inactive');
BEGIN
	RETURN (
		(first_active IS NOT NULL AND first_private IS NOT NULL AND first_active < first_private) OR
		(first_active IS NOT NULL AND first_inactive IS NOT NULL AND first_active < first_inactive)
	);
END;
$$;



--
--

CREATE FUNCTION is_more_public(statuses text[]) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	first_active integer := array_position(statuses, 'active');
	first_private integer := array_position(statuses, 'private');
	first_inactive integer := array_position(statuses, 'inactive');
BEGIN
	RETURN (
		(first_active IS NOT NULL AND first_private IS NOT NULL AND first_private < first_active) OR
		(first_active IS NOT NULL AND first_inactive IS NOT NULL AND first_inactive < first_active) OR
		(first_private IS NOT NULL AND first_inactive IS NOT NULL AND first_private < first_inactive)
	);
END;
$$;



SET default_tablespace = '';

SET default_with_oids = false;

--
--

CREATE TABLE accounts (
    id integer NOT NULL,
    paste_id integer,
    network_id integer,
    name text
);



--
--

CREATE SEQUENCE accounts_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE accounts_id_seq OWNED BY accounts.id;


--
--

CREATE TABLE accounts_was_abused (
    id integer NOT NULL,
    account_id integer,
    was_abused boolean
);



--
--

CREATE SEQUENCE accounts_was_abused_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE accounts_was_abused_id_seq OWNED BY accounts_was_abused.id;


--
--

CREATE TABLE accounts_went_private (
    id integer NOT NULL,
    account_id integer,
    went_private boolean
);



--
--

CREATE SEQUENCE accounts_went_private_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE accounts_went_private_id_seq OWNED BY accounts_went_private.id;


--
--

CREATE TABLE comments (
    id integer NOT NULL,
    post_id integer,
    is_abusive boolean DEFAULT false,
    text text,
    commenter text,
    pete_is_abusive boolean,
    metadata jsonb,
    pete_is_abusive_2 boolean
);



--
--

CREATE SEQUENCE comments_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE comments_id_seq OWNED BY comments.id;


--
--

CREATE TABLE crawls (
    id integer NOT NULL,
    account_id integer,
    delta integer DEFAULT 0,
    created_on timestamp without time zone DEFAULT now(),
    status_id integer,
    body text
);



--
--

CREATE SEQUENCE crawls_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE crawls_id_seq OWNED BY crawls.id;


--
--

CREATE TABLE genders (
    id integer NOT NULL,
    name text,
    short text
);



--
--

CREATE SEQUENCE genders_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE genders_id_seq OWNED BY genders.id;


--
--

CREATE TABLE mentions (
    id integer NOT NULL,
    crawl_id integer,
    text text,
    commenter text,
    is_abusive boolean,
    metadata jsonb
);



--
--

CREATE SEQUENCE mentions_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE mentions_id_seq OWNED BY mentions.id;


--
--

CREATE TABLE networks (
    id integer NOT NULL,
    name text
);



--
--

CREATE SEQUENCE networks_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE networks_id_seq OWNED BY networks.id;


--
--

CREATE TABLE pastes (
    id integer NOT NULL,
    source_id integer,
    is_dox boolean,
    title text,
    syntax text,
    "user" text,
    key text,
    full_url text,
    scrape_url text,
    body text,
    hash text,
    added_on timestamp without time zone,
    expires_on timestamp without time zone,
    created_on timestamp without time zone DEFAULT now(),
    is_deleted integer DEFAULT 0,
    gender_id integer,
    is_dupe boolean DEFAULT false
);



--
--

COMMENT ON COLUMN pastes.title IS 'Provided title for the dox file';


--
--

COMMENT ON COLUMN pastes."user" IS 'Provided user name of the person submitting the dox';


--
--

COMMENT ON COLUMN pastes.key IS 'Unique identifier, provided by the website, to identify this dox';


--
--

COMMENT ON COLUMN pastes.full_url IS 'The URL that the dox file could be viewed on in a browser';


--
--

COMMENT ON COLUMN pastes.scrape_url IS 'The URL that the dox file was scrapped from';


--
--

COMMENT ON COLUMN pastes.is_deleted IS '0 indicates not measured, 1 is deleted, 2 is not deleted.  These measurements are as of 10/12/2016.';


--
--

CREATE VIEW pastes_dataset AS
 SELECT pastes.id,
    pastes.source_id,
    pastes.is_dox,
    pastes.title,
    pastes.syntax,
    pastes."user",
    pastes.key,
    pastes.full_url,
    pastes.scrape_url,
    pastes.body,
    pastes.hash,
    pastes.added_on,
    pastes.expires_on,
    pastes.created_on,
    pastes.is_deleted,
    pastes.gender_id,
    pastes.is_dupe
   FROM pastes
  WHERE ((pastes.created_on >= '2016-11-30 00:00:00'::timestamp without time zone) AND (pastes.created_on <= '2017-02-06 00:00:00'::timestamp without time zone) AND (pastes.expires_on IS NULL));



--
--

CREATE SEQUENCE pastes_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE pastes_id_seq OWNED BY pastes.id;


--
--

CREATE TABLE pastes_views (
    id integer NOT NULL,
    paste_id integer,
    created_on timestamp without time zone,
    num_views integer DEFAULT 0,
    delta integer
);



--
--

COMMENT ON COLUMN pastes_views.num_views IS 'The number of times a paste has been viewed.  -1 means the post does not exist anymore, and -2 means the post is not public anymore.';


--
--

CREATE SEQUENCE pastes_views_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE pastes_views_id_seq OWNED BY pastes_views.id;


--
--

CREATE TABLE posts (
    id integer NOT NULL,
    crawl_id integer,
    body text,
    comments_checked boolean DEFAULT false
);



--
--

CREATE SEQUENCE posts_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE posts_id_seq OWNED BY posts.id;


--
--

CREATE TABLE sources (
    id integer NOT NULL,
    name text,
    url text
);



--
--

CREATE SEQUENCE sources_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE sources_id_seq OWNED BY sources.id;


--
--

CREATE TABLE statuses (
    id integer NOT NULL,
    name text
);



--
--

CREATE SEQUENCE statuses_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



--
--

ALTER SEQUENCE statuses_id_seq OWNED BY statuses.id;


--
--

ALTER TABLE ONLY accounts ALTER COLUMN id SET DEFAULT nextval('accounts_id_seq'::regclass);


--
--

ALTER TABLE ONLY accounts_was_abused ALTER COLUMN id SET DEFAULT nextval('accounts_was_abused_id_seq'::regclass);


--
--

ALTER TABLE ONLY accounts_went_private ALTER COLUMN id SET DEFAULT nextval('accounts_went_private_id_seq'::regclass);


--
--

ALTER TABLE ONLY comments ALTER COLUMN id SET DEFAULT nextval('comments_id_seq'::regclass);


--
--

ALTER TABLE ONLY crawls ALTER COLUMN id SET DEFAULT nextval('crawls_id_seq'::regclass);


--
--

ALTER TABLE ONLY genders ALTER COLUMN id SET DEFAULT nextval('genders_id_seq'::regclass);


--
--

ALTER TABLE ONLY mentions ALTER COLUMN id SET DEFAULT nextval('mentions_id_seq'::regclass);


--
--

ALTER TABLE ONLY networks ALTER COLUMN id SET DEFAULT nextval('networks_id_seq'::regclass);


--
--

ALTER TABLE ONLY pastes ALTER COLUMN id SET DEFAULT nextval('pastes_id_seq'::regclass);


--
--

ALTER TABLE ONLY pastes_views ALTER COLUMN id SET DEFAULT nextval('pastes_views_id_seq'::regclass);


--
--

ALTER TABLE ONLY posts ALTER COLUMN id SET DEFAULT nextval('posts_id_seq'::regclass);


--
--

ALTER TABLE ONLY sources ALTER COLUMN id SET DEFAULT nextval('sources_id_seq'::regclass);


--
--

ALTER TABLE ONLY statuses ALTER COLUMN id SET DEFAULT nextval('statuses_id_seq'::regclass);


--
--

ALTER TABLE ONLY accounts
    ADD CONSTRAINT accounts_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY accounts_was_abused
    ADD CONSTRAINT accounts_was_abused_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY accounts_went_private
    ADD CONSTRAINT accounts_went_private_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY comments
    ADD CONSTRAINT comments_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY crawls
    ADD CONSTRAINT crawls_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY genders
    ADD CONSTRAINT genders_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY mentions
    ADD CONSTRAINT mentions_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY networks
    ADD CONSTRAINT networks_name_key UNIQUE (name);


--
--

ALTER TABLE ONLY networks
    ADD CONSTRAINT networks_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY pastes
    ADD CONSTRAINT pastes_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY pastes_views
    ADD CONSTRAINT pastes_views_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY posts
    ADD CONSTRAINT posts_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY sources
    ADD CONSTRAINT sources_name_key UNIQUE (name);


--
--

ALTER TABLE ONLY sources
    ADD CONSTRAINT sources_pkey PRIMARY KEY (id);


--
--

ALTER TABLE ONLY statuses
    ADD CONSTRAINT statuses_name_key UNIQUE (name);


--
--

ALTER TABLE ONLY statuses
    ADD CONSTRAINT statuses_pkey PRIMARY KEY (id);


--
--

CREATE INDEX accounts_network_id_idx ON accounts USING btree (network_id);


--
--

CREATE INDEX accounts_paste_id_idx ON accounts USING btree (paste_id);


--
--

CREATE INDEX accounts_was_abused_account_id_idx ON accounts_was_abused USING btree (account_id);


--
--

CREATE INDEX accounts_was_abused_was_abused_idx ON accounts_was_abused USING btree (was_abused);


--
--

CREATE INDEX accounts_went_private_account_id_idx ON accounts_went_private USING btree (account_id);


--
--

CREATE INDEX comments_crawl_id_idx ON comments USING btree (post_id);


--
--

CREATE INDEX comments_is_abusive_idx ON comments USING btree (is_abusive);


--
--

CREATE INDEX crawls_account_id_idx ON crawls USING btree (account_id);


--
--

CREATE INDEX crawls_created_on_idx ON crawls USING btree (created_on);


--
--

CREATE INDEX crawls_delta_idx ON crawls USING btree (delta);


--
--

CREATE INDEX mentions_crawl_id_idx ON mentions USING btree (crawl_id);


--
--

CREATE INDEX mentions_is_abusive_idx ON mentions USING btree (is_abusive);


--
--

CREATE INDEX pastes_added_on_idx ON pastes USING btree (added_on);


--
--

CREATE INDEX pastes_created_on_idx ON pastes USING btree (created_on);


--
--

CREATE INDEX pastes_is_deleted_idx ON pastes USING btree (is_deleted);


--
--

CREATE INDEX pastes_is_dox_idx ON pastes USING btree (is_dox);


--
--

CREATE INDEX pastes_is_dupe_idx ON pastes USING btree (is_dupe);


--
--

CREATE UNIQUE INDEX pastes_key_source_id_idx ON pastes USING btree (key, source_id);


--
--

CREATE INDEX pastes_source_id_idx ON pastes USING btree (source_id);


--
--

CREATE INDEX pastes_views_created_on_idx ON pastes_views USING btree (created_on);


--
--

CREATE INDEX pastes_views_paste_id_created_on_idx ON pastes_views USING btree (paste_id, created_on);


--
--

CREATE INDEX pastes_views_paste_id_delta_idx ON pastes_views USING btree (paste_id, delta);


--
--

CREATE INDEX pastes_views_paste_id_idx ON pastes_views USING btree (paste_id);


--
--

CREATE INDEX posts_comments_checked_idx ON posts USING btree (comments_checked);


--
--

CREATE INDEX posts_crawl_id_idx ON posts USING btree (crawl_id);


--
--

CREATE INDEX sources_name_idx ON sources USING btree (name);


--
--

ALTER TABLE ONLY accounts
    ADD CONSTRAINT accounts_network_id_fkey FOREIGN KEY (network_id) REFERENCES networks(id);


--
--

ALTER TABLE ONLY accounts
    ADD CONSTRAINT accounts_paste_id_fkey FOREIGN KEY (paste_id) REFERENCES pastes(id);


--
--

ALTER TABLE ONLY accounts_was_abused
    ADD CONSTRAINT accounts_was_abused_account_id_fkey FOREIGN KEY (account_id) REFERENCES accounts(id);


--
--

ALTER TABLE ONLY accounts_went_private
    ADD CONSTRAINT accounts_went_private_account_id_fkey FOREIGN KEY (account_id) REFERENCES accounts(id);


--
--

ALTER TABLE ONLY comments
    ADD CONSTRAINT comments_post_id_fkey FOREIGN KEY (post_id) REFERENCES posts(id);


--
--

ALTER TABLE ONLY crawls
    ADD CONSTRAINT crawls_account_id_fkey FOREIGN KEY (account_id) REFERENCES accounts(id) ON DELETE CASCADE;


--
--

ALTER TABLE ONLY crawls
    ADD CONSTRAINT crawls_status_id_fkey FOREIGN KEY (status_id) REFERENCES statuses(id);


--
--

ALTER TABLE ONLY mentions
    ADD CONSTRAINT mentions_crawl_id_fkey FOREIGN KEY (crawl_id) REFERENCES crawls(id);


--
--

ALTER TABLE ONLY pastes
    ADD CONSTRAINT pastes_gender_id_fkey FOREIGN KEY (gender_id) REFERENCES genders(id);


--
--

ALTER TABLE ONLY pastes
    ADD CONSTRAINT pastes_source_id_fkey FOREIGN KEY (source_id) REFERENCES sources(id);


--
--

ALTER TABLE ONLY pastes_views
    ADD CONSTRAINT pastes_views_paste_id_fkey FOREIGN KEY (paste_id) REFERENCES pastes(id);


--
--

ALTER TABLE ONLY posts
    ADD CONSTRAINT posts_crawl_id_fkey FOREIGN KEY (crawl_id) REFERENCES crawls(id) ON DELETE CASCADE;


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
--

REVOKE ALL ON TABLE accounts FROM PUBLIC;
GRANT ALL ON TABLE accounts TO doxing;


--
--

REVOKE ALL ON SEQUENCE accounts_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE accounts_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE accounts_was_abused FROM PUBLIC;
GRANT ALL ON TABLE accounts_was_abused TO doxing;


--
--

REVOKE ALL ON TABLE accounts_went_private FROM PUBLIC;
GRANT ALL ON TABLE accounts_went_private TO doxing;


--
--

REVOKE ALL ON TABLE comments FROM PUBLIC;
GRANT ALL ON TABLE comments TO doxing;


--
--

REVOKE ALL ON SEQUENCE comments_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE comments_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE crawls FROM PUBLIC;
GRANT ALL ON TABLE crawls TO doxing;


--
--

REVOKE ALL ON SEQUENCE crawls_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE crawls_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE genders FROM PUBLIC;
GRANT ALL ON TABLE genders TO doxing;


--
--

REVOKE ALL ON SEQUENCE genders_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE genders_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE mentions FROM PUBLIC;
GRANT ALL ON TABLE mentions TO doxing;


--
--

REVOKE ALL ON SEQUENCE mentions_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE mentions_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE networks FROM PUBLIC;
GRANT ALL ON TABLE networks TO doxing;


--
--

REVOKE ALL ON SEQUENCE networks_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE networks_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE pastes FROM PUBLIC;
GRANT ALL ON TABLE pastes TO doxing;


--
--

REVOKE ALL ON TABLE pastes_dataset FROM PUBLIC;
GRANT ALL ON TABLE pastes_dataset TO doxing;


--
--

REVOKE ALL ON SEQUENCE pastes_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE pastes_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE pastes_views FROM PUBLIC;
GRANT ALL ON TABLE pastes_views TO doxing;


--
--

REVOKE ALL ON SEQUENCE pastes_views_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE pastes_views_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE posts FROM PUBLIC;
GRANT ALL ON TABLE posts TO doxing;


--
--

REVOKE ALL ON SEQUENCE posts_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE posts_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE sources FROM PUBLIC;
GRANT ALL ON TABLE sources TO doxing;


--
--

REVOKE ALL ON SEQUENCE sources_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE sources_id_seq TO doxing;


--
--

REVOKE ALL ON TABLE statuses FROM PUBLIC;
GRANT ALL ON TABLE statuses TO doxing;


--
--

REVOKE ALL ON SEQUENCE statuses_id_seq FROM PUBLIC;
GRANT ALL ON SEQUENCE statuses_id_seq TO doxing;


--
--



--
-- PostgreSQL database dump complete
--

