#!/usr/bin/env python

import argparse
import logging
import time
import doxaccountrecrawler.reporting
import doxaccountrecrawler.recrawling

PARSER = argparse.ArgumentParser(description="Submit accounts for rescraping "
                                             "that were previously scraped")
PARSER.add_argument('-d', '--dburl', required=True,
                    help="Domain and (optional) port to connect to the "
                         "database connector webservice")
PARSER.add_argument('-s', '--social', required=True,
                    help="Domain and (optional) port to connect to the "
                         "social service scraper webservice")
PARSER.add_argument('-l', '--logdir', default=None,
                    help="The directory to write logging information to.")
PARSER.add_argument('-v', '--verbose', action="store_true",
                    help="Whether to print out verbose informational "
                         "messages to STDOUT")
ARGS = PARSER.parse_args()


doxaccountrecrawler.reporting.configure_logger(ARGS.logdir, ARGS.verbose)

LOGGER = logging.getLogger("dox-account-recrawler.log")

RECRAWL_ROUNDS = list(range(1, 10))
RECRAWL_ROUNDS.reverse()

while True:
    for RECRAWL_NUM in RECRAWL_ROUNDS:
        recrawl_params = (ARGS.dburl, ARGS.social, RECRAWL_NUM)
        NUM_SUCCESSES = doxaccountrecrawler.recrawling.recrawl_all(*recrawl_params)
        if NUM_SUCCESSES is None:
            log_params = {
                "num": RECRAWL_NUM
            }
            LOGGER.error("Failed to recrawl for index: %(num)s", log_params)
            time.sleep(10)
            continue
        else:
            log_params = {
                "count": NUM_SUCCESSES,
                "num": RECRAWL_NUM,
            }
            LOGGER.info("Successfully recrawled %(count)s accounts for index: "
                        "%(num)s", log_params)
    time.sleep(120)
