#!/usr/bin/env python
import os
import argparse
import tornado.web
import tornado.ioloop
import doxscrapers.reporting
import doxscrapers.controllers


CUR_DIR = os.path.dirname(os.path.realpath(__file__))

PARSER = argparse.ArgumentParser(description="Scrapes information about a "
                                             "user's social networking account")

PARSER.add_argument('-p', '--port', default=8888, type=int,
                    help="The port the webserver should listen on.")
PARSER.add_argument('-i', '--ip', default="0.0.0.0",
                    help="The IP address to listen on.")
PARSER.add_argument('-b', '--binary', default=None,
                    help="Path to the firefox binary (Default: result of "
                         "`which`)")
PARSER.add_argument('-l', '--logdir', default=None,
                    help="Path to write logs to.")
PARSER.add_argument('-v', '--verbose', action="store_true",
                    help="Enables debugging / verbose logging.")
ARGS = PARSER.parse_args()


doxscrapers.controllers.set_arg("CUR_DIR", CUR_DIR)
doxscrapers.controllers.set_arg("BINARY", ARGS.binary)

FIREFOX_LOG = doxscrapers.reporting.configure_logger(ARGS.logdir, ARGS.verbose)
doxscrapers.controllers.set_arg("LOG_FILE", FIREFOX_LOG)


SETTINGS = {
    "debug": ARGS.verbose,
    "log_function": doxscrapers.reporting.http_error_logger,
}

APPLICATION = tornado.web.Application([
    (r"/scrape", doxscrapers.controllers.SocialExtractionHandler),
], **SETTINGS)
APPLICATION.listen(ARGS.port, address=ARGS.ip)
tornado.ioloop.IOLoop.current().start()
