#!/usr/bin/env python
import argparse
import tornado.web
import tornado.ioloop
import momoko
import dbconnector.controllers
import dbconnector.reporting
import config

PARSER = argparse.ArgumentParser(description="Web service for managing "
                                             "persistent information about "
                                             "dox files.")
PARSER.add_argument('-p', '--port', default=8888, type=int,
                    help="The port the webserver should listen on.")
PARSER.add_argument('-i', '--ip', default="0.0.0.0",
                    help="The IP address to listen on.")
PARSER.add_argument('-l', '--log', default=None,
                    help="Path to write logs to.")
PARSER.add_argument('-v', '--verbose', action="store_true",
                    help="Enables debugging / verbose logging.")
ARGS = PARSER.parse_args()

IOLOOP = tornado.ioloop.IOLoop.instance()

CONN = momoko.Pool(config.postgres, size=4)

# Check to make sure that we can connect to the database with the given
# database parameters
FUTURE = CONN.connect()
IOLOOP.add_future(FUTURE, lambda x: IOLOOP.stop())
IOLOOP.start()
FUTURE.result()

SETTINGS = {
    "debug": ARGS.verbose,
    "log_function": dbconnector.reporting.http_error_logger,
}

APPLICATION = tornado.web.Application([
    (r'/does-paste-exist', dbconnector.controllers.DoesPasteExistController),
    (r'/record-paste', dbconnector.controllers.RecordPasteController),
    (r'/record-social-account', dbconnector.controllers.RecordSocialAccountController),
    (r'/record-crawl', dbconnector.controllers.RecordSocialAccountCrawlController),
    (r'/accounts-to-recrawl', dbconnector.controllers.AccountsForNthRecrawl),
    (r'/pastes-to-count-views', dbconnector.controllers.PasteBinKeysToCountViewsController),
    (r'/record-views-for-paste', dbconnector.controllers.RecordViewsForPasteController),
], **SETTINGS)

dbconnector.reporting.configure_logger(ARGS.log, ARGS.verbose)

APPLICATION.listen(ARGS.port, address=ARGS.ip)
APPLICATION.db = CONN
tornado.ioloop.IOLoop.current().start()
